@@ -8,21 +8,24 @@ OC.L10N.register(
     "Rename" : "Hernoem",
     "Move" : "Skuif",
     "Delete" : "Skrap",
-    "Save" : "Stoor",
+    "Search" : "Soek",
+    "New" : "Nuut",
     "New folder" : "Nuwe vouer",
     "List view" : "Lysaansig",
-    "Create" : "Skep",
+    "Select all" : "Kies alle",
     "Cancel" : "Kanselleer",
+    "Recent" : "Onlangs",
+    "Add a bookmark" : "Voeg 'n boekmerk by",
     "Import" : "Voer In",
     "Export" : "Voer uit",
     "Recently added" : "Onlangs bygevoeg",
     "Alphabetically" : "Alfabeties",
     "Most visited" : "Meeste besoek",
     "Last modified" : "Laas gewysig",
-    "RSS Feed" : "RSS-voer",
-    "Delete all bookmarks" : "Skrap alle boekmerke",
     "Bookmarklet" : "Boekmerkie",
-    "URL" : "Bronadres",
+    "Delete all bookmarks" : "Skrap alle boekmerke",
+    "Title" : "Titel",
+    "Link" : "Skakel",
     "Tags" : "Merkers",
     "Notes" : "Notas",
     "Owner" : "Eienaar",
@@ -33,10 +36,8 @@ OC.L10N.register(
     "Select" : "Kies",
     "Previews" : "Voorskoue",
     "Privacy" : "Privaatheid",
-    "Add a bookmark" : "Voeg 'n boekmerk by",
     "This URL is already bookmarked! Overwrite?" : "'n Boekmerk van die URL bestaan reeds. Skryf oor?",
-    "Title" : "Titel",
-    "Link" : "Skakel",
-    "Folder" : "Vouer"
+    "Folder" : "Vouer",
+    "Save" : "Stoor"
 },
 "nplurals=2; plural=(n != 1);");
