@@ -8,33 +8,36 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Borrar",
-    "Save" : "Guardar",
+    "Search" : "Buscar",
+    "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
     "Grid view" : "Vista de cuadrícula",
     "List view" : "Vista de lista",
-    "Create" : "Crear",
+    "Select all" : "Seleccionar todo",
+    "Submit" : "Enviar",
     "Cancel" : "Cancelar",
-    "Public" : "Público",
+    "Recent" : "Reciente",
+    "Add a bookmark" : "Agregar un marcador",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Recently added" : "Agregado recientemente",
     "Alphabetically" : "Alfabéticamente",
     "Last modified" : "Última modificación",
-    "Clear data" : "Borrar datos",
     "Bookmarklet" : "Marcador a código ",
-    "URL" : "URL",
+    "Clear data" : "Borrar datos",
+    "Title" : "Título",
+    "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
-    "Sharing" : "Compartiendo",
     "Owner" : "Dueño",
+    "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
     "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
     "Select" : "Seleccionar",
     "Privacy" : "Privacidad",
-    "Add a bookmark" : "Agregar un marcador",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
-    "Title" : "Título",
-    "Link" : "Liga"
+    "Folder" : "Carpeta",
+    "Save" : "Guardar"
 },
 "nplurals=2; plural=(n != 1);");
