@@ -9,11 +9,13 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Move" : "Mover",
     "Delete" : "Borrar",
+    "Search" : "Buscar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva ",
     "Grid view" : "Vista de cuadrícula",
     "List view" : "Vista de lista",
     "Select all" : "Seleccionar todo",
+    "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos los marcadores",
     "Recent" : "Reciente",
