@@ -18,6 +18,7 @@ OC.L10N.register(
     "Import" : "Увези",
     "Export" : "Извези",
     "Recently added" : "Скоро додадени",
+    "Alphabetically" : "Азбучно",
     "Last modified" : "Скоро изменети",
     "Clear data" : "Исчисти податоци",
     "Title" : "Наслов",
@@ -27,10 +28,12 @@ OC.L10N.register(
     "Notes" : "Белешки",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
+    "Select a user or group" : "Избери корисник или група",
     "Share link" : "Сподели линк",
     "Copy link" : "Копирај линк",
     "Copy RSS feed" : "Копирај RSS канал",
     "Allow editing" : "Овозможи уредување",
+    "Remove share" : "Отстрани споделување",
     "Link copied" : "Линкот е копиран",
     "RSS feed copied" : "RSS канал копиран",
     "Select" : "Select",
