@@ -28,6 +28,7 @@ OC.L10N.register(
     "No file provided for import" : "Inga filer given för importering",
     "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Bookmarks shared by %s" : "Bokmärken delas av %s",
+    "Recent Bookmarks" : "Senaste bokmärken",
     "Bookmark" : "Bokmärke",
     "Bookmark deleted" : "Bokmärke raderat",
     "Bookmark created" : "Bokmärke skapat",
@@ -41,7 +42,8 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Rename" : "Byt namn",
     "Move" : "Flytta",
-    "Delete" : "Radera",
+    "Delete" : "Ta bort",
+    "Search" : "Sök",
     "Select one or more tags" : "Välj en eller flera taggar",
     "New" : "Nytt",
     "New bookmark" : "Nytt bokmärke",
@@ -49,7 +51,7 @@ OC.L10N.register(
     "Grid view" : "Rutnätsvy",
     "List view" : "Listvy",
     "Move selection" : "Flytta urval",
-    "Delete selection" : "Radera urval",
+    "Delete selection" : "Ta bort urval",
     "Open all selected" : "Öppna alla markerade",
     "Select all" : "Välj alla",
     "Cancel selection" : "Avbryt markering",
@@ -61,6 +63,7 @@ OC.L10N.register(
     "Enter folder title" : "Ange titel",
     "Shared by {user}" : "Delad av {user}",
     "Root folder" : "Topp-mapp",
+    "Submit" : "Verkställ",
     "Cancel" : "Avbryt",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
     "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
@@ -112,7 +115,7 @@ OC.L10N.register(
     "Share link" : "Dela länk",
     "Copy link" : "Kopiera länk",
     "Copy RSS feed" : "Kopiera RSS-flöde",
-    "Delete link" : "Radera länk",
+    "Delete link" : "Ta bort länk",
     "Create public link" : "Skapa offentlig länk",
     "Allow editing" : "Tillåt redigering",
     "Allow sharing" : "Tillåt delning",
