@@ -2,31 +2,79 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "書籤",
+    "You bookmarked \"%s\"" : "您已建立書籤 \"%s\"",
+    "%1$s bookmarked \"%2$s\"" : "%1$s 建立書籤 \"%2$s\"",
+    "Someone bookmarked \"%s\"" : "有人建立書籤 \"%s\"",
+    "You deleted \"%s\"" : "您已刪除 \"%s\"",
+    "%1$s deleted \"%2$s\"" : "%1$s 已刪除 \"%2$s\"",
+    "Someone deleted \"%s\"" : "有人刪除 \"%s\"",
+    "You created folder \"%s\"" : "您已建立資料夾 \"%s\"",
+    "%1$s created folder \"%2$s\"" : "%1$s 已建立資料夾 \"%2$s\"",
+    "Someone created folder \"%s\"" : "有人建立資料夾 \"%s\"",
+    "You moved folder \"%s\"" : "您已移動資料夾 \"%s\"",
+    "%1$s moved folder \"%2$s\"" : "%1$s 已移動資料夾 \"%2$s\"",
+    "Someone moved folder \"%s\"" : "有人移動資料夾 \"%s\"",
+    "You deleted folder \"%s\"" : "您已刪除資料夾 \"%s\"",
+    "%1$s deleted folder \"%2$s\"" : "%1$s 已刪除資料夾 \"%2$s\"",
+    "Someone deleted folder \"%s\"" : "有人刪除資料夾 \"%s\"",
+    "You shared folder \"%1$s\" with %2$s" : "您已與 %2$s 共用 \"%1$s\" ",
+    "You shared folder \"%s\" with someone" : "您已與某人共用 \"%s\"",
+    "%1$s shared folder \"%2$s\" with you" : "%1$s 已共用資料夾 \"%2$s\" 給您",
+    "Someone shared folder \"%s\" with you" : "有人共用資料夾 \"%s\" 給您",
+    "You unshared folder \"%1$s\" with %2$s" : "您已取消與 %2$s 共用的資料夾 \"%1$s\"",
+    "You unshared folder \"%s\" with someone" : "您已取消與某人共用的資料夾 \"%s\"",
+    "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您共用的資料夾 \"%2$s\" ",
+    "Someone unshared folder \"%s\" with you" : "某人已取消與你共用的資料夾 \"%s\"",
     "No file provided for import" : "無匯入檔案",
     "Unsupported file type for import" : "匯入不支援的檔案格式",
+    "Bookmarks shared by %s" : "由 %s 共用的書籤",
+    "Recent Bookmarks" : "最近的書籤",
+    "Bookmark" : "書籤",
+    "Bookmark deleted" : "書籤已刪除",
+    "Bookmark created" : "書籤已建立",
+    "Bookmark moved" : "書籤已移動",
+    "Bookmark updated" : "書籤已更新",
+    "Create bookmark" : "已建立書籤",
     "A Bookmark manager for Nextcloud" : "Nextcloud上的書籤管理員",
+    "Enter new title" : "輸入新的標題",
     "Select bookmark" : "選擇書籤",
     "Details" : "細節",
     "Rename" : "重新命名",
     "Move" : "移動",
     "Delete" : "刪除",
+    "Search" : "搜尋",
     "Select one or more tags" : "選擇一個或是多個標記",
     "New" : "新增",
+    "New bookmark" : "新增書籤",
     "New folder" : "新增資料夾",
     "Grid view" : "網格檢視",
     "List view" : "清單檢視",
     "Move selection" : "移動選擇",
     "Delete selection" : "刪除選擇",
+    "Open all selected" : "開啟所有選取對象",
     "Select all" : "全選",
+    "Cancel selection" : "取消選取",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["選擇 %n 書籤"],
+    "_Selected %n folder_::_Selected %n folders_" : ["已選取 %n 個資料夾"],
     "Enter a link" : "輸入一個連結",
+    "Enter a title" : "輸入標題",
+    "No bookmarks found" : "未發現書籤",
+    "Select folder" : "選擇資料夾",
     "Enter folder title" : "輸入資料夾標題",
+    "Shared by {user}" : "由 {user} 共用",
     "Root folder" : "根目錄",
+    "Submit" : "送出",
     "Cancel" : "取消",
+    "Deleting bookmarks" : "刪除書籤",
+    "Deleting selection" : "刪除選擇",
+    "Importing bookmarks" : "匯入書籤",
+    "Moving selection" : "移動選擇",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n資料夾和一些書籤"],
     "_Moving %n folder_::_Moving %n folders_" : ["移動%n個資料夾"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
+    "All bookmarks" : "所有書籤",
     "Recent" : "近期",
+    "Archived" : "已封存",
     "Untagged" : "未標記",
     "No bookmarks here" : "無書籤",
     "Add a bookmark" : "新增書籤",
