@@ -1,11 +1,9 @@
 <?php
 
-/**
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
+/*
+ * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
  *
- * @author Stefan Klemm <mail@stefan-klemm.de>
- * @copyright Stefan Klemm 2014
+ * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
 
 namespace OCA\Bookmarks\Controller;
@@ -26,6 +24,7 @@ use OCP\AppFramework\Http\StreamResponse;
 use OCP\AppFramework\Http\Template\PublicTemplateResponse;
 use OCP\IL10N;
 use OCP\IRequest;
+use OCP\IURLGenerator;
 use OCP\IUserManager;
 
 class WebViewController extends Controller {
@@ -52,7 +51,7 @@ class WebViewController extends Controller {
 	 */
 	private $folderMapper;
 	/**
-	 * @var \OCP\IURLGenerator
+	 * @var IURLGenerator
 	 */
 	private $urlGenerator;
 	/**
@@ -75,11 +74,11 @@ class WebViewController extends Controller {
 	 * @param PublicFolderMapper $publicFolderMapper
 	 * @param IUserManager $userManager
 	 * @param FolderMapper $folderMapper
-	 * @param \OCP\IURLGenerator $urlGenerator
+	 * @param IURLGenerator $urlGenerator
 	 * @param \OCP\IInitialStateService $initialState
 	 * @param FoldersController $folderController
 	 */
-	public function __construct($appName, $request, $userId, IL10N $l, PublicFolderMapper $publicFolderMapper, IUserManager $userManager, \OCA\Bookmarks\Db\FolderMapper $folderMapper, \OCP\IURLGenerator $urlGenerator, \OCP\IInitialStateService $initialState, \OCA\Bookmarks\Controller\FoldersController $folderController) {
+	public function __construct($appName, $request, $userId, IL10N $l, PublicFolderMapper $publicFolderMapper, IUserManager $userManager, FolderMapper $folderMapper, IURLGenerator $urlGenerator, \OCP\IInitialStateService $initialState, \OCA\Bookmarks\Controller\FoldersController $folderController) {
 		parent::__construct($appName, $request);
 		$this->userId = $userId;
 		$this->l = $l;
