@@ -61,12 +61,12 @@ class PageresBookmarkPreviewer implements IBookmarkPreviewer {
 	protected function fetchImage(string $serverPath, string $url): ?Image {
 		$tempPath = $this->tempManager->getTemporaryFile('.png');
 		$tempDir = dirname($tempPath);
-		$tempFile = basename($tempPath);
+		$tempFile = basename($tempPath, '.png');
 		$command = $serverPath;
 		$escapedUrl = escapeshellarg($url);
 
-		$cmd = "cd {$tempDir} && {$command} {$escapedUrl} desktop" .
-			' --delay=4 --filename=' . escapeshellarg($tempFile) . ' --overwrite 2>&1';
+		$cmd = "cd {$tempDir} && {$command} {$escapedUrl} 1024x768" .
+			' --delay=4 --filename=' . escapeshellarg($tempFile) . ' --crop --overwrite 2>&1';
 
 		$retries = 0;
 		$output = [];
